import { useContext, useEffect, useState } from 'react';
import SUIContext from '@s-ui/react-context';
import { TCF_VERSION, TCF_WINDOW_API } from './config';
import hasUserConsents from './hasUserConsents';
import { EventStatus } from './types';
export default function useUserConsents(requiredConsents) {
    /**
     * Consents acceptance state is inited based on the cookies from the
     * context, so we know the state of consents from the beginning, even
     * in SSR.
     */
    var cookies = useContext(SUIContext).cookies;
    var _a = useState(function () { return hasUserConsents({ requiredConsents: requiredConsents, cookies: cookies }); }), areConsentsAccepted = _a[0], setAreConsentsAccepted = _a[1];
    /**
     * From then on, we listen for TCF events so consents changes
     * can be catched right away, no matter when, and react to them
     * wherever the hook is used.
     */
    useEffect(function () {
        var tcfApi = window[TCF_WINDOW_API];
        if (tcfApi !== undefined) {
            var consentsListener_1 = function (_a) {
                var eventStatus = _a.eventStatus, purpose = _a.purpose;
                if (eventStatus !== EventStatus.USER_ACTION_COMPLETE)
                    return;
                setAreConsentsAccepted(requiredConsents.every(function (purposeId) { return Boolean(purpose.consents[purposeId]); }));
            };
            tcfApi('addEventListener', TCF_VERSION, consentsListener_1);
            return function () {
                tcfApi('removeEventListener', TCF_VERSION, consentsListener_1);
            };
        }
    }, [requiredConsents]);
    return areConsentsAccepted;
}
